@@ -1,7 +1,8 @@
 #!/usr/bin/env bash
-
 # For a clean conda environment please read docs/source/dev_install.md
 
+set -x
+
 echo -n "Checking pip... "
 pip --version
 if [ $? -ne 0 ]; then
@@ -32,10 +33,13 @@ echo -n "widgetsnbextension"
 pip install -v -e ./python/widgetsnbextension
 if [[ "$OSTYPE" == "msys" ]]; then
     jupyter nbextension install --overwrite --py $nbExtFlags widgetsnbextension || true
+    jupyter nbclassic-extension install --overwrite --py $nbExtFlags widgetsnbextension || true
 else
     jupyter nbextension install --overwrite --py --symlink $nbExtFlags widgetsnbextension || true
+    jupyter nbclassic-extension install --overwrite --py --symlink $nbExtFlags widgetsnbextension || true
 fi
 jupyter nbextension enable --py $nbExtFlags widgetsnbextension || true
+jupyter nbclassic-extension enable --py $nbExtFlags widgetsnbextension || true
 
 echo -n "ipywidgets"
 pip install -v -e "./python/ipywidgets[test]"
